hadrian-reppas opened a new pull request, #553: URL: https://github.com/apache/datasketches-cpp/pull/553
I was benchmarking DataSketches against other HLL implementations and the union was slower than expected. It turns out this loop was not getting vectorized. With this change, taking a union goes from 1222ns to 144ns on my machine. -- This is an automated message from the Apache Git Service. To respond to the message, please log on to GitHub and use the URL above to go to the specific comment. To unsubscribe, e-mail: [email protected] For queries about this service, please contact Infrastructure at: [email protected] --------------------------------------------------------------------- To unsubscribe, e-mail: [email protected] For additional commands, e-mail: [email protected]
